<?php
/*
Plugin Name: ZycoonApps Custom CSS JS
Plugin URI: https://www.zycoonapps.com/wordpress-apps/zycoonapps-custom-css-js.html
Description: Add Custom css/js on any page or sitewide.
Version: 2.0.0
Author: ZycoonApps
Author URI: https://www.zycoonapps.com/
License: GPLv2 or later
Text Domain: zycoonapps-custom-css-js
*/

defined('ABSPATH') or die();
function zapps_customcssjs_register_posttype() {
    $domain = 'zapps-custom-css-js';
    $labels = array(
        'name'                => _x( 'Custom CSS / JS', 'Post Type General Name', $domain ),
        'singular_name'       => _x( 'Code', 'Post Type Singular Name', $domain ),
        'menu_name'           => __( 'zApps CSS/JS', $domain ),
        'parent_item_colon'   => __( 'Parent Code', $domain ),
        'all_items'           => __( 'All CSS/JS', $domain ),
        'view_item'           => __( 'View Code', $domain ),
        'add_new_item'        => __( 'Add New Code', $domain ),
        'add_new'             => __( 'Add New', $domain ),
        'edit_item'           => __( 'Edit Code', $domain ),
        'update_item'         => __( 'Update Code', $domain ),
        'search_items'        => __( 'Search Code', $domain ),
        'not_found'           => __( 'Not Found', $domain ),
        'not_found_in_trash'  => __( 'Not found in Trash', $domain ),
    );
    $args = array(
        'description'         => __( 'ZycoonApps Custom CSS / JS', $domain ),
        'labels'              => $labels,
        'supports'            => array( 'title', 'revisions','editor'),
        'menu_icon'           => 'dashicons-schedule',
        'hierarchical'        => false,
        'public'              => false,
        'show_ui'             => true,
        'show_in_menu'        => true,
        'show_in_nav_menus'   => true,
        'show_in_admin_bar'   => false,
        'menu_position'       => 56,
        'can_export'          => true,
        'has_archive'         => true,
        'exclude_from_search' => true,
        'query_var'              => false,
        'publicly_queryable'  => false,
        'capability_type'        => 'post',
        'show_in_rest' => true,
 
    );
    register_post_type( 'zapps-custom-css-js', $args );
}
add_action( 'init', 'zapps_customcssjs_register_posttype' );

add_filter( 'post_row_actions', 'my_cpt_row_actions', 10, 2 );
function my_cpt_row_actions( $actions, $post ) {
    if ( 'zapps-custom-css-js' === $post->post_type ) {
        unset( $actions['inline hide-if-no-js'] );
    }
    return $actions;
}

add_filter('use_block_editor_for_post_type', 'prefix_disable_gutenberg', 10, 2);
function prefix_disable_gutenberg($current_status, $post_type)
{
    if ($post_type === 'zapps-custom-css-js') return false;
    return $current_status;
}

function zapps_customcssjs_loader( $hook ) {
    global $post;
    if($post->post_type != 'zapps-custom-css-js')
    {
        add_filter('user_can_richedit', '__return_false');
        remove_action( 'media_buttons', 'media_buttons' );
        add_action('admin_footer', 'zapps_customcssjs_admin_css_js');
        zapps_customcssjs_load_admin();
    }
}
add_action( 'init', 'zapps_customcssjs_loader' );

function zapps_customcssjs_admin_css_js() {
    echo '<style>
    body.post-type-zapps-custom-css-js #visibility, body.post-type-zapps-custom-css-js #post-status-info, body.post-type-zapps-custom-css-js #ed_toolbar {
        display:none !important;
    }
    body.post-type-zapps-custom-css-js textarea#content {
        margin-top:0px !important;
    }
    .zapps-customcssjs {
        background-color:#666666;
        display: inline-block;
        padding: 3px 10px;
        color: #fff;
        font-weight: normal;
        border-radius: 3px;
        width: 70px;
        text-align: center;
        margin-right: 5px;
        text-transform: uppercase;
    }
    .zapps-customcssjs-css {
        background-color:#0085de;
    }
    .zapps-customcssjs-js {
        background-color:#5a19ba;
    }
    .zapps-customcssjs-html {
        background-color:#19baba;
    }
    </style>';
}

function zapps_customcssjs_load_admin() {
    define('ZAPPS_CSSJS_DOMAIN', 'zapps-custom-css-js');
    $prefix = 'zapps_cssjs_';
    $fields = array(
        array( 
            'label'                     => __('Code Type',       ZAPPS_CSSJS_DOMAIN),
            'desc'                      => __('Select code type.', ZAPPS_CSSJS_DOMAIN), 
            'id'                        => $prefix . 'code_type',
            'type'                      => 'radio',
            'options'                   => array(
                array(
                    'value'=>'css',
                    'label'=>__('CSS', ZAPPS_CSSJS_DOMAIN)
                    ),
                array(
                    'value'=>'js',
                    'label'=>__('JS', ZAPPS_CSSJS_DOMAIN)
                    ),
                array(
                    'value'=>'html',
                    'label'=>__('HTML', ZAPPS_CSSJS_DOMAIN)
                    )
                )
            ),
        array( 
            'label'                     => __('Load in',       ZAPPS_CSSJS_DOMAIN),
            'desc'                      => __('Load in', ZAPPS_CSSJS_DOMAIN), 
            'id'                        => $prefix . 'code_loadin',
            'type'                      => 'radio',
            'options'                   => array(
                array(
                    'value'=>'header',
                    'label'=>__('Header', ZAPPS_CSSJS_DOMAIN)
                    ),
                array(
                    'value'=>'footer',
                    'label'=>__('Footer', ZAPPS_CSSJS_DOMAIN)
                    )
                )
            ),
        array( 
            'label'                     => __('Load on',       ZAPPS_CSSJS_DOMAIN),
            'desc'                      => __('Load on', ZAPPS_CSSJS_DOMAIN), 
            'id'                        => $prefix . 'code_loadon',
            'type'                      => 'radio',
            'options'                   => array(
                array(
                    'value'=>'frontend',
                    'label'=>__('Frontend', ZAPPS_CSSJS_DOMAIN)
                    ),
                array(
                    'value'=>'backend',
                    'label'=>__('Backend', ZAPPS_CSSJS_DOMAIN)
                    )
                )
            ),
        array( 
            'label'                     => __('Priority',       ZAPPS_CSSJS_DOMAIN),
            'desc'                      => __('Load Sequence', ZAPPS_CSSJS_DOMAIN), 
            'id'                        => $prefix . 'code_priority',
            'type'                      => 'select',
            'options'                   => array(
    
                array(
                    'value'=>'1',
                    'label'=>__('1 (Highest)', ZAPPS_CSSJS_DOMAIN)
                    ),   
                array(
                    'value'=>'2',
                    'label'=>__('2', ZAPPS_CSSJS_DOMAIN)
                    ),          
                array(
                    'value'=>'3',
                    'label'=>__('3', ZAPPS_CSSJS_DOMAIN)
                    ),
                array(
                    'value'=>'4',
                    'label'=>__('4', ZAPPS_CSSJS_DOMAIN)
                    ),
                array(
                    'value'=>'5',
                    'label'=>__('5', ZAPPS_CSSJS_DOMAIN)
                    ),
                array(
                    'value'=>'6',
                    'label'=>__('6', ZAPPS_CSSJS_DOMAIN)
                    ),
                array(
                    'value'=>'7',
                    'label'=>__('7', ZAPPS_CSSJS_DOMAIN)
                    ),
                array(
                    'value'=>'8',
                    'label'=>__('8', ZAPPS_CSSJS_DOMAIN)
                    ),
                array(
                    'value'=>'9',
                    'label'=>__('9', ZAPPS_CSSJS_DOMAIN)
                    ),
                array(
                    'value'=>'10',
                    'label'=>__('10 (Lowest)', ZAPPS_CSSJS_DOMAIN)
                    ),
                )
            )
        );
    new zApps_Customcssjs_Add_Meta_Box( 'zapps_page_box', __('Settings', ZAPPS_CSSJS_DOMAIN), $fields, 'zapps-custom-css-js', true );
}

class zApps_Customcssjs_Add_Meta_Box {
	var $id;
	var $title;
	var $fields;
	var $page;
	
	public function __construct( $id, $title, $fields, $page ) {
		$this->id = $id;
		$this->title = $title;
		$this->fields = $fields;
		$this->page = $page;
		if( ! is_array( $this->page ) )
			$this->page = array( $this->page );
		add_action( 'add_meta_boxes', array( $this, 'zapps_customcssjs_add_box' ) );
		add_action( 'save_post',  array( $this, 'zapps_customcssjs_save_box' ));
	}

	function zapps_customcssjs_add_box() {
		foreach ( $this->page as $page ) {
			add_meta_box( $this->id, $this->title, array( $this, 'zapps_customcssjs_meta_box_callback' ), $page, 'side', 'high' );
		}
	}

    function zapps_customcssjs_meta_box_field( $field, $meta = null, $repeatable = null ) {
    	if ( ! ( $field || is_array( $field ) ) )
    		return;
    	
    	$type = isset( $field['type'] ) ? $field['type'] : null;
    	$label = isset( $field['label'] ) ? $field['label'] : null;
    	$desc = isset( $field['desc'] ) ? '<span class="description">' . $field['desc'] . '</span>' : null;
    	$place = isset( $field['place'] ) ? $field['place'] : null;
    	$size = isset( $field['size'] ) ? $field['size'] : null;
    	$post_type = isset( $field['post_type'] ) ? $field['post_type'] : null;
    	$options = isset( $field['options'] ) ? $field['options'] : null;
    	$settings = isset( $field['settings'] ) ? $field['settings'] : null;
    	$repeatable_fields = isset( $field['repeatable_fields'] ) ? $field['repeatable_fields'] : null;
    	
    	$id = $name = isset( $field['id'] ) ? $field['id'] : null;
    	if ( $repeatable ) {
    		$name = $repeatable[0] . '[' . $repeatable[1] . '][' . $id .']';
    		$id = $repeatable[0] . '_' . $repeatable[1] . '_' . $id;
    	}
    	switch( $type ) {
    		case 'radio':
    		echo '<ul class="meta_box_items" style="margin: 10px;">';
    		$selected = 0;
    		$selectedtype = "";
    		foreach ( $options as $option )
    		{
    			if($meta==$option['value'])
    			{
    			    $selected = 1;
    			    $selectedtype = $option['value'];
    			}
    		}
    		if($selected==1 && $name=="zapps_cssjs_code_type")
    		{
        		echo "<b style='text-transform:uppercase;'>".$selectedtype."</b> / ";
        		echo "<b>";
        		if($selectedtype=="js") { echo "Javascript"; }
        		if($selectedtype=="css") { echo "Stylesheet"; }
        		if($selectedtype=="html") { echo "HTML Code"; }
        		echo "</b>";
    		}
    		else
    		{
        		foreach ( $options as $option )
        		{
        		    if($selected==0)
        		    {
        		        echo '<li><input type="radio" name="' . esc_attr( $name ) . '" id="' . esc_attr( $id ) . '-' . $option['value'] . '" value="' . $option['value'] . '" checked />
        		<label for="' . esc_attr( $id ) . '-' . $option['value'] . '">' . $option['label'] . '</label></li>';
        		        $selected=1;
        		    }
        		    else
        		    {
        		        echo '<li><input type="radio" name="' . esc_attr( $name ) . '" id="' . esc_attr( $id ) . '-' . $option['value'] . '" value="' . $option['value'] . '" ' . checked( $meta, $option['value'], false ) . ' />
        		<label for="' . esc_attr( $id ) . '-' . $option['value'] . '">' . $option['label'] . '</label></li>';
        		    }
        		}
    		}
    		echo '</ul>';
    		break;	
    		case 'select':
    		echo '<select name="' . esc_attr( $name ) . '" id="' . esc_attr( $id ) . '"' , $type == 'chosen' ? ' class="chosen"' : '' , isset( $multiple ) && $multiple == true ? ' multiple="multiple"' : '' , '>'; // Select One  <option value="">Select One</option>';
    		foreach ( $options as $option )
    		echo '<option' . selected( $meta, $option['value'], false ) . ' value="' . $option['value'] . '">' . $option['label'] . '</option>';
    		echo '</select><br />';
    		break;
    	}
    }

	function zapps_customcssjs_meta_box_callback() {
		wp_nonce_field( 'custom_meta_box_nonce_action', 'custom_meta_box_nonce_field' );
		echo '<table class="form-table meta_box">';
		foreach ( $this->fields as $field) {
			if ( $field['type'] == 'radio' ) {
				echo '<tr>
				<th colspan="2" style="padding: 0px;"><label for="' . $field['id'] . '">' . $field['label'] . '</label></th>
				</tr>';
				echo '<tr style="margin-bottom:10px;display:block;">
				<td colspan="2" style="padding: 0px;">';
				$meta = get_post_meta( get_the_ID(), $field['id'], true);
				echo zApps_Customcssjs_Add_Meta_Box::zapps_customcssjs_meta_box_field( $field, $meta );
				echo     '</td>
				</tr>';
			}
			elseif ( $field['type'] == 'select' ) {
				echo '<tr>
				<th colspan="2" style="padding: 0px;"><label for="' . $field['id'] . '">' . $field['label'] . '</label></th>
				</tr>';
				echo '<tr style="margin-bottom:10px;display:block;">
				<td colspan="2" style="padding: 0px;">';
				$meta = get_post_meta( get_the_ID(), $field['id'], true);
				echo zApps_Customcssjs_Add_Meta_Box::zapps_customcssjs_meta_box_field( $field, $meta );
				echo     '</td>
				</tr>';
			}
			else {
				echo '<tr>
				<th colspan="2" style="padding: 0px;"><label for="' . $field['id'] . '">' . $field['label'] . '</label></th>
				<td>';
				$meta = get_post_meta( get_the_ID(), $field['id'], true);
				echo zApps_Customcssjs_Add_Meta_Box::zapps_customcssjs_meta_box_field( $field, $meta );
				echo     '</td>
				</tr>';
			}
		}
		echo '</table>';
	}

	function zapps_customcssjs_save_box( $post_id ) {
		$post_type = get_post_type();
		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE )
			return $post_id;
		foreach($this->fields as $field)
		{
			if(isset($_POST[$field['id']]))
			{
				$new = (int) sanitize_text_field($_POST[$field['id']]);
				update_post_meta($post_id,$field['id'],$new);
                if($field['id']=="zapps_cssjs_code_priority")
			    {
			        global $wpdb;
			        $table = $wpdb->prefix.'posts';
                    $data =array(
                        'menu_order' => $new
                    );
                    $wherecondition=array(
                        'ID'=>$post_id
                    );
                    $wpdb->update($table,$data,$wherecondition);
			    }
			}
		}
	}
}

// List view: Display Custom Data - START
    add_filter('manage_zapps-custom-css-js_posts_columns', function($columns) {
    	$offset = array_search('date', array_keys($columns));
    	return array_merge(array_slice($columns, 0, $offset), ['zapps_cssjs_code_type' => __('Type', 'textdomain')], array_slice($columns, $offset, null));
    });
    add_filter('manage_zapps-custom-css-js_posts_columns', function($columns) {
    	$offset = array_search('date', array_keys($columns));
    	return array_merge(array_slice($columns, 0, $offset), ['zapps_cssjs_code_loadin' => __('Load In', 'textdomain')], array_slice($columns, $offset, null));
    });
    add_filter('manage_zapps-custom-css-js_posts_columns', function($columns) {
    	$offset = array_search('date', array_keys($columns));
    	return array_merge(array_slice($columns, 0, $offset), ['zapps_cssjs_code_loadon' => __('Load On', 'textdomain')], array_slice($columns, $offset, null));
    });
     
    add_action('manage_zapps-custom-css-js_posts_custom_column', function($column_key, $post_id) {
    	$metaData = get_post_meta($post_id, $column_key, true );
    	$metaDataLoadin = get_post_meta($post_id, "zapps_cssjs_code_loadin", true );
    	$metaDataLoadon = get_post_meta($post_id, "zapps_cssjs_code_loadon", true );
    	if ($column_key == 'zapps_cssjs_code_type') {
    		if($metaData=="js")
    		{
    		    echo "<div class='zapps-customcssjs zapps-customcssjs-js'>".$metaData."</div>";
    		}
    		if($metaData=="css")
    		{
    		    echo "<div class='zapps-customcssjs zapps-customcssjs-css'>".$metaData."</div>";
    		}
    		if($metaData=="html")
    		{
    		    echo "<div class='zapps-customcssjs zapps-customcssjs-html'>".$metaData."</div>";
    		}
    	}
    	if ($column_key == 'zapps_cssjs_code_loadin') {
    		echo "<div class='zapps-customcssjs'>".$metaData."</div>";
    	}
    	if ($column_key == 'zapps_cssjs_code_loadon') {
    		echo "<div class='zapps-customcssjs'>".$metaData."</div>";
    	}
    }, 10, 2);
// List view: Display Custom Data - END

// Fontend (Loader / START)
add_action( 'init', 'zapps_customcssjs_loader_frontend' );
function zapps_customcssjs_loader_frontend()
{
    $cssjs_posts = get_posts([
      'post_type' => 'zapps-custom-css-js',
      'post_status' => 'publish',
      'numberposts' => -1,
      'orderby' => 'menu_order',
      'order' => 'ASC'
    ]);
    
    $data_cssjs = array();
    foreach($cssjs_posts as $cssjs_posts_single)
    {
        $postmeta = get_post_meta($cssjs_posts_single->ID);
        $content = $cssjs_posts_single->post_content;
        $type = $postmeta['zapps_cssjs_code_type'][0];
        $loadin = $postmeta['zapps_cssjs_code_loadin'][0];
        $loadon = $postmeta['zapps_cssjs_code_loadon'][0];
        if($type && $loadin && $loadon)
        {
            $data_cssjs[$loadon][$loadin][$type] .= $content."\n";
        }
    }

    foreach($data_cssjs as $data_cssjs_key => $data_cssjs_single)
    {
    	switch( $data_cssjs_key ) {
    		case 'backend':
    		    foreach($data_cssjs_single as $data_cssjs_key_key => $data_cssjs_single_single)
    		    {
                	switch( $data_cssjs_key_key ) {
                		case 'header':
                		    if($data_cssjs_single_single['js'])
                            add_action('admin_head', function () use ($data_cssjs_single_single) { echo "\n<script>\n".$data_cssjs_single_single['js']."\n</script>\n"; } );
                            if($data_cssjs_single_single['css'])
                            add_action('admin_head', function () use ($data_cssjs_single_single) { echo "\n<style>\n".$data_cssjs_single_single['css']."\n</style>\n"; } );
                            if($data_cssjs_single_single['html'])
                            add_action('admin_head', function () use ($data_cssjs_single_single) { echo "\n".$data_cssjs_single_single['html']."\n"; } );
                		break;	
                		case 'footer':
                		    if($data_cssjs_single_single['js'])
                            add_action('admin_footer', function () use ($data_cssjs_single_single) { echo "\n<script>\n".$data_cssjs_single_single['js']."\n</script>\n"; } );
                            if($data_cssjs_single_single['css'])
                            add_action('admin_footer', function () use ($data_cssjs_single_single) { echo "\n<style>\n".$data_cssjs_single_single['css']."\n</style>\n"; } );
                            if($data_cssjs_single_single['html'])
                            add_action('admin_footer', function () use ($data_cssjs_single_single) { echo "\n".$data_cssjs_single_single['html']."\n"; } );
                		break;	
                	}
    		    }
    		break;	
    		case 'frontend':
    		    foreach($data_cssjs_single as $data_cssjs_key_key => $data_cssjs_single_single)
    		    {
                	switch( $data_cssjs_key_key ) {
                		case 'header':
                		    if($data_cssjs_single_single['js'])
                            add_action('wp_head', function () use ($data_cssjs_single_single) { echo "\n<script>\n".$data_cssjs_single_single['js']."\n</script>\n"; } );
                            if($data_cssjs_single_single['css'])
                            add_action('wp_head', function () use ($data_cssjs_single_single) { echo "\n<style>\n".$data_cssjs_single_single['css']."\n</style>\n"; } );
                            if($data_cssjs_single_single['html'])
                            add_action('wp_head', function () use ($data_cssjs_single_single) { echo "\n".$data_cssjs_single_single['html']."\n"; } );
                		break;	
                		case 'footer':
                		    if($data_cssjs_single_single['js'])
                            add_action('wp_footer', function () use ($data_cssjs_single_single) { echo "\n<script>\n".$data_cssjs_single_single['js']."\n</script>\n"; } );
                            if($data_cssjs_single_single['css'])
                            add_action('wp_footer', function () use ($data_cssjs_single_single) { echo "\n<style>\n".$data_cssjs_single_single['css']."\n</style>\n"; } );
                            if($data_cssjs_single_single['html'])
                            add_action('wp_footer', function () use ($data_cssjs_single_single) { echo "\n".$data_cssjs_single_single['html']."\n"; } );
                		break;	
                	}
    		    }
    		break;	
    	}
    }
}
// Fontend (Loader / END)




?>